@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,43 +26,44 @@
 #include "vpiano.h"
 #include "vpianosettings.h"
 
-const QString PGM_DESCRIPTION = QCoreApplication::tr(
+const char* PGM_DESCRIPTION = QT_TRANSLATE_NOOP("QCoreApplication",
      "Virtual MIDI Piano Keyboard\n"
-     "Copyright (C) 2006-2021 Pedro Lopez-Cabanillas\n"
+     "Copyright (C) 2006-2022 Pedro Lopez-Cabanillas\n"
      "This program comes with ABSOLUTELY NO WARRANTY;\n"
      "This is free software, and you are welcome to redistribute it\n"
      "under certain conditions; see the LICENSE for details.");
 
 int main(int argc, char *argv[])
 {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) &&  (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
+    QApplication app(argc, argv);
     QCoreApplication::setOrganizationName(QSTR_DOMAIN);
     QCoreApplication::setOrganizationDomain(QSTR_DOMAIN);
     QCoreApplication::setApplicationName(QSTR_APPNAME);
     QCoreApplication::setApplicationVersion(PGM_VERSION);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
     QCoreApplication::setAttribute(Qt::AA_SynthesizeMouseForUnhandledTouchEvents, false);
     QCoreApplication::setAttribute(Qt::AA_SynthesizeTouchForUnhandledMouseEvents, false);
 #if defined(Q_OS_WINDOWS)
     QApplication::setStyle("fusion");
-#endif
-    QApplication app(argc, argv);
-#if defined(Q_OS_LINUX)
+#elif defined(Q_OS_LINUX)
     app.setWindowIcon(QIcon(":/vpiano/vmpk_32x32.png"));
 #endif //Q_OS_LINUX
 
+    VPianoSettings::instance()->loadTranslations();
+
     QCommandLineParser parser;
-    parser.setApplicationDescription(QString("%1 v.%2\n\n%3").arg(
+    parser.setApplicationDescription(QString("%1 v%2\n\n%3").arg(
         QCoreApplication::applicationName(),
         QCoreApplication::applicationVersion(),
-        PGM_DESCRIPTION));
+        QCoreApplication::tr(PGM_DESCRIPTION)));
     auto helpOption = parser.addHelpOption();
     auto versionOption = parser.addVersionOption();
     QCommandLineOption portableOption({"p", "portable"}, QCoreApplication::tr("Portable settings mode."));
-    QCommandLineOption portableFileName("f", "file", QCoreApplication::tr("Portable settings file name."), "portableFile");
+    QCommandLineOption portableFileOption({"f", "file"}, QCoreApplication::tr("Portable settings file name."), "file");
     parser.addOption(portableOption);
-    parser.addOption(portableFileName);
+    parser.addOption(portableFileOption);
     parser.process(app);
     if (parser.isSet(versionOption) || parser.isSet(helpOption)) {
         return 0;
@@ -78,10 +79,10 @@ int main(int argc, char *argv[])
     splash.showMessage("Virtual MIDI Piano Keyboard " + PGM_VERSION, Qt::AlignBottom | Qt::AlignRight);
     app.processEvents();
 
-    if (parser.isSet(portableOption) || parser.isSet(portableFileName)) {
+    if (parser.isSet(portableOption) || parser.isSet(portableFileOption)) {
         QString portableFile;
-        if (parser.isSet(portableFileName)) {
-            portableFile = parser.value(portableFileName);
+        if (parser.isSet(portableFileOption)) {
+            portableFile = parser.value(portableFileOption);
         }
         VPianoSettings::setPortableConfig(portableFile);
     } else {
