@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include <QDialog>
 #include <QUrl>
 #include <QString>
-#include <QTranslator>
 #include <QMapIterator>
 #include <QShortcut>
 #include <QActionGroup>
@@ -79,7 +78,10 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     m_midiin(nullptr),
     m_backendManager(nullptr),
     m_initialized(false),
-    m_filter(nullptr)
+#if defined(ENABLE_NATIVE_FILTER)	
+    m_filter(nullptr),
+#endif	
+    m_currentLang(nullptr)
 {
 #if defined(ENABLE_DBUS)
     new VmpkAdaptor(this);
@@ -87,26 +89,6 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     dbus.registerObject("/", this);
     dbus.registerService("net.sourceforge.vmpk");
 #endif
-    m_trq = new QTranslator(this);
-    m_trp = new QTranslator(this);
-    m_trl = new QTranslator(this);
-    QString lang = VPianoSettings::instance()->language();
-    if (!m_trq->load(QSTR_QTPX + lang, VPianoSettings::systemLocales()) && !lang.startsWith("en")) {
-        qWarning() << "Failure loading Qt5 system translations for" << lang
-                   << "from" << VPianoSettings::systemLocales();
-    }
-    if (!m_trp->load(QSTR_VMPKPX + lang, VPianoSettings::localeDirectory()) && !lang.startsWith("en")) {
-        qWarning() << "Failure loading VMPK application translations for" << lang
-                   << "from" << VPianoSettings::localeDirectory();
-    }
-    if (!m_trl->load(QSTR_DRUMSTICKPX + lang, VPianoSettings::drumstickLocales()) && !lang.startsWith("en")) {
-        qWarning() << "Failure loading widgets library translations for" << lang
-                   << "from" << VPianoSettings::drumstickLocales();
-    }
-    QCoreApplication::installTranslator(m_trq);
-    QCoreApplication::installTranslator(m_trp);
-    QCoreApplication::installTranslator(m_trl);
-    VPianoSettings::instance()->retranslatePalettes();
     ui.setupUi(this);
     initLanguages();
 
@@ -179,7 +161,7 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     //ui.actionExitFullScreen->setShortcut(QKeySequence::FullScreen);
 #endif
     ui.pianokeybd->setPianoHandler(this);
-#if defined(RAWKBD_SUPPORT)
+#if defined(RAWKBD_SUPPORT) && defined(ENABLE_NATIVE_FILTER)
     m_filter = new NativeFilter;
     m_filter->setRawKbdHandler(ui.pianokeybd);
     qApp->installNativeEventFilter(m_filter);
@@ -189,7 +171,7 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
 
 VPiano::~VPiano()
 {
-#if defined(RAWKBD_SUPPORT)
+#if defined(RAWKBD_SUPPORT) && defined(ENABLE_NATIVE_FILTER)
     m_filter->setRawKbdEnabled(false);
     qApp->removeNativeEventFilter(m_filter);
     delete m_filter;
@@ -1288,8 +1270,9 @@ void VPiano::applyPreferences()
     {
         ui.pianokeybd->setNumKeys(VPianoSettings::instance()->numKeys(), VPianoSettings::instance()->startingKey());
     }
-#if defined(RAWKBD_SUPPORT)
+#if defined(RAWKBD_SUPPORT) && defined(ENABLE_NATIVE_FILTER)
     m_filter->setRawKbdEnabled(VPianoSettings::instance()->rawKeyboard());
+    ui.pianokeybd->setUsingNativeFilter(VPianoSettings::instance()->rawKeyboard());
 #endif
     ui.pianokeybd->setRawKeyboardMode(VPianoSettings::instance()->rawKeyboard());
     ui.pianokeybd->setVelocityTint(VPianoSettings::instance()->velocityColor());
@@ -1310,18 +1293,21 @@ void VPiano::applyPreferences()
     qApp->setPalette( VPianoSettings::instance()->getDarkMode() ? darkPalette : defaultPalette );
     qApp->setStyle( VPianoSettings::instance()->getStyle() );
 
-    VMPKKeyboardMap* map = VPianoSettings::instance()->getKeyboardMap();
-    if (!map->getFileName().isEmpty() && map->getFileName() != QSTR_DEFAULT )
-        ui.pianokeybd->setKeyboardMap(map);
-    else
-        ui.pianokeybd->resetKeyboardMap();
-
-    map = VPianoSettings::instance()->getRawKeyboardMap();
-    if (!map->getFileName().isEmpty() && map->getFileName() != QSTR_DEFAULT )
-        ui.pianokeybd->setRawKeyboardMap(map);
-    else
-        ui.pianokeybd->resetRawKeyboardMap();
-
+	if (VPianoSettings::instance()->rawKeyboard()) {
+		VMPKKeyboardMap* map = VPianoSettings::instance()->getRawKeyboardMap();
+		if (!map->getFileName().isEmpty() && map->getFileName() != QSTR_DEFAULT ) {
+			ui.pianokeybd->setRawKeyboardMap(map);
+		} else {
+			ui.pianokeybd->resetRawKeyboardMap();
+		}
+	} else {
+		VMPKKeyboardMap* map = VPianoSettings::instance()->getKeyboardMap();
+		if (!map->getFileName().isEmpty() && map->getFileName() != QSTR_DEFAULT ) {
+			ui.pianokeybd->setKeyboardMap(map);
+		} else {
+			ui.pianokeybd->resetKeyboardMap();
+		}
+	}
     PianoPalette highlight = VPianoSettings::instance()->getPalette(VPianoSettings::instance()->highlightPaletteId());
     ui.pianokeybd->setHighlightPalette(highlight);
     PianoPalette background = VPianoSettings::instance()->getPalette(VPianoSettings::instance()->colorScale() ? PAL_SCALE : PAL_KEYS);
@@ -1334,12 +1320,10 @@ void VPiano::applyPreferences()
 
     QPoint wpos = pos();
     Qt::WindowFlags flags = windowFlags();
-    if (VPianoSettings::instance()->alwaysOnTop())
-        flags |= Qt::WindowStaysOnTopHint;
-    else
-        flags &= ~Qt::WindowStaysOnTopHint;
+    flags.setFlag( Qt::WindowStaysOnTopHint, VPianoSettings::instance()->alwaysOnTop() );
     setWindowFlags( flags );
     move(wpos);
+    show();
 }
 
 void VPiano::populateInstruments()
@@ -1637,15 +1621,17 @@ void VPiano::slotComboControlCurrentIndexChanged(const int index)
 
 void VPiano::grabKb()
 {
-#if defined(RAWKBD_SUPPORT)
+#if defined(RAWKBD_SUPPORT) && defined(ENABLE_NATIVE_FILTER)
     m_filter->setRawKbdEnabled(VPianoSettings::instance()->rawKeyboard());
+    ui.pianokeybd->setUsingNativeFilter(VPianoSettings::instance()->rawKeyboard());
 #endif
 }
 
 void VPiano::releaseKb()
 {
-#if defined(RAWKBD_SUPPORT)
+#if defined(RAWKBD_SUPPORT) && defined(ENABLE_NATIVE_FILTER)
     m_filter->setRawKbdEnabled(false);
+    ui.pianokeybd->setUsingNativeFilter(false);
 #endif
 }
 
@@ -1959,6 +1945,9 @@ void VPiano::slotSwitchLanguage(QAction *action)
         VPianoSettings::instance()->setLanguage(lang);
         retranslateUi();
     } else {
+        if (m_currentLang == nullptr) {
+            m_currentLang = action;
+        }
         m_currentLang->setChecked(true);
     }
 }
@@ -1966,13 +1955,20 @@ void VPiano::slotSwitchLanguage(QAction *action)
 void VPiano::createLanguageMenu()
 {
     QString currentLang = VPianoSettings::instance()->language();
+    if (currentLang.isEmpty()) {
+        QLocale locale;
+        if (locale.language() == QLocale::C || locale.language() == QLocale::English)
+            currentLang = "C";
+        else
+            currentLang = locale.name().left(2);
+    }
     QActionGroup *languageGroup = new QActionGroup(this);
     languageGroup->setExclusive(true);
     connect(languageGroup, &QActionGroup::triggered, this, &VPiano::slotSwitchLanguage, Qt::QueuedConnection);
     QDir dir(VPianoSettings::localeDirectory());
     QStringList fileNames = dir.entryList(QStringList(QSTR_VMPKPX + "*.qm"));
     QStringList locales;
-    locales << "en";
+    locales << "C";
     foreach (const QString& fileName, fileNames) {
         QString locale = fileName;
         locale.remove(0, locale.indexOf('_') + 1);
@@ -2002,7 +1998,7 @@ void VPiano::slotAboutTranslation()
         "</p>");
     QString currentLang = VPianoSettings::instance()->language();
     bool supported(false);
-    if (!currentLang.startsWith("en")) {
+    if (!currentLang.isEmpty() && (currentLang != "C")) {
         QMapIterator<QString,QString> it(m_supportedLangs);
         while (it.hasNext())  {
             it.next();
@@ -2021,10 +2017,7 @@ void VPiano::slotAboutTranslation()
 
 void VPiano::retranslateUi()
 {
-    m_trq->load(QSTR_QTPX + VPianoSettings::instance()->language(), VPianoSettings::systemLocales());
-    m_trp->load(QSTR_VMPKPX + VPianoSettings::instance()->language(), VPianoSettings::localeDirectory());
-    m_trl->load(QSTR_DRUMSTICKPX + VPianoSettings::instance()->language(), VPianoSettings::drumstickLocales());
-    VPianoSettings::instance()->retranslatePalettes();
+    VPianoSettings::instance()->loadTranslations();
     ui.retranslateUi(this);
     ui.pianokeybd->retranslate();
     initLanguages();
@@ -2036,9 +2029,9 @@ void VPiano::retranslateUi()
 void VPiano::initLanguages()
 {
     m_supportedLangs.clear();
+    m_supportedLangs.insert(QLatin1String("C"), tr("English"));
     m_supportedLangs.insert(QLatin1String("cs"), tr("Czech"));
     m_supportedLangs.insert(QLatin1String("de"), tr("German"));
-    m_supportedLangs.insert(QLatin1String("en"), tr("English"));
     m_supportedLangs.insert(QLatin1String("es"), tr("Spanish"));
     m_supportedLangs.insert(QLatin1String("fr"), tr("French"));
     m_supportedLangs.insert(QLatin1String("gl"), tr("Galician"));
@@ -2165,18 +2158,14 @@ void VPiano::slotColorScale(bool value)
 
 void VPiano::toggleWindowFrame(const bool state)
 {
+    QPoint wpos = pos();
     Qt::WindowFlags flags = windowFlags();
-
-    if (state)
-        flags &= ~Qt::FramelessWindowHint;
-    else
-        flags |= Qt::FramelessWindowHint;
-
+    flags.setFlag( Qt::FramelessWindowHint, !state );
     setWindowFlags(flags);
+    move(wpos);
     show();
 }
 
-
 void VPiano::slotNameOrientation(QAction* action)
 {
     if(action == ui.actionHorizontal) {
