@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +20,11 @@
 #define VPIANO_H
 
 #include <QMainWindow>
+#include <QPointer>
 #include <drumstick/pianokeybd.h>
-#include "nativefilter.h"
+#if defined(ENABLE_NATIVE_FILTER)
+	#include "nativefilter.h"
+#endif
 #include "instrument.h"
 #include "ui_vpiano.h"
 
@@ -29,7 +32,6 @@
 #include "winsnap.h"
 #endif
 
-class QTranslator;
 class QLabel;
 class QComboBox;
 class QSpinBox;
@@ -228,7 +230,9 @@ private:
 
     bool m_initialized;
 
+#if defined(ENABLE_NATIVE_FILTER)
     NativeFilter *m_filter;
+#endif
 
     Ui::VPiano ui;
 
@@ -257,7 +261,6 @@ private:
     QMap<int,int> m_lastProg;
     QMap<int,int> m_lastCtl;
     QMap<QString, QString> m_supportedLangs;
-    QTranslator *m_trq, *m_trp, *m_trl;
     QAction *m_currentLang;
     QHash<QString,QList<QKeySequence> > m_defaultShortcuts;
 #if defined(Q_OS_WINDOWS)
